@@ -31,6 +31,11 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->lineEdit->setValidator(new QRegExpValidator(regexer_icon, ui->lineEdit));
     ui->lineEdit_2->setValidator(new QRegExpValidator(regexer_book, ui->lineEdit_2));
     ui->Snap->setValidator(new QRegExpValidator(regexer_snap, ui->Snap));
+    QImage png("/opt/theme-customizer/customizer.png");
+    QPixmap image;
+    image = image.fromImage(png);
+    ui->logo->setPixmap(image);
+    ui->logo->setGeometry(0,0,79,900);
 
 }
 
